Documentation
¶
Overview ¶
Package obs exports types, functions, subpackages for provisioning obs resources.
Index ¶
- type Bucket
- type BucketArgs
- type BucketInput
- type BucketOutput
- func (o BucketOutput) Ak() pulumi.StringOutput
- func (o BucketOutput) Bucket_name() pulumi.StringOutput
- func (BucketOutput) ElementType() reflect.Type
- func (o BucketOutput) Endpoint() pulumi.StringOutput
- func (o BucketOutput) Location() pulumi.StringOutput
- func (o BucketOutput) Result() pulumi.StringOutput
- func (o BucketOutput) Sk() pulumi.StringOutput
- func (o BucketOutput) ToBucketOutput() BucketOutput
- func (o BucketOutput) ToBucketOutputWithContext(ctx context.Context) BucketOutput
- type BucketState
- type Provider
- type ProviderArgs
- type ProviderInput
- type ProviderOutput
- type Random
- type RandomArgs
- type RandomComponent
- type RandomComponentArgs
- type RandomComponentInput
- type RandomComponentOutput
- func (RandomComponentOutput) ElementType() reflect.Type
- func (o RandomComponentOutput) Length() pulumi.IntOutput
- func (o RandomComponentOutput) Password() pulumi.StringOutput
- func (o RandomComponentOutput) ToRandomComponentOutput() RandomComponentOutput
- func (o RandomComponentOutput) ToRandomComponentOutputWithContext(ctx context.Context) RandomComponentOutput
- type RandomInput
- type RandomOutput
- type RandomState
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Bucket ¶
type Bucket struct {
pulumi.CustomResourceState
Ak pulumi.StringOutput `pulumi:"ak"`
Bucket_name pulumi.StringOutput `pulumi:"bucket_name"`
Endpoint pulumi.StringOutput `pulumi:"endpoint"`
Location pulumi.StringOutput `pulumi:"location"`
Result pulumi.StringOutput `pulumi:"result"`
Sk pulumi.StringOutput `pulumi:"sk"`
}
func GetBucket ¶
func GetBucket(ctx *pulumi.Context, name string, id pulumi.IDInput, state *BucketState, opts ...pulumi.ResourceOption) (*Bucket, error)
GetBucket gets an existing Bucket resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).
func NewBucket ¶
func NewBucket(ctx *pulumi.Context, name string, args *BucketArgs, opts ...pulumi.ResourceOption) (*Bucket, error)
NewBucket registers a new resource with the given unique name, arguments, and options.
func (*Bucket) ElementType ¶
func (*Bucket) ToBucketOutput ¶
func (i *Bucket) ToBucketOutput() BucketOutput
func (*Bucket) ToBucketOutputWithContext ¶
func (i *Bucket) ToBucketOutputWithContext(ctx context.Context) BucketOutput
type BucketArgs ¶
type BucketArgs struct {
Ak pulumi.StringInput
Bucket_name pulumi.StringInput
Endpoint pulumi.StringInput
Location pulumi.StringInput
Sk pulumi.StringInput
}
The set of arguments for constructing a Bucket resource.
func (BucketArgs) ElementType ¶
func (BucketArgs) ElementType() reflect.Type
type BucketInput ¶
type BucketInput interface {
pulumi.Input
ToBucketOutput() BucketOutput
ToBucketOutputWithContext(ctx context.Context) BucketOutput
}
type BucketOutput ¶
type BucketOutput struct{ *pulumi.OutputState }
func (BucketOutput) Ak ¶
func (o BucketOutput) Ak() pulumi.StringOutput
func (BucketOutput) Bucket_name ¶
func (o BucketOutput) Bucket_name() pulumi.StringOutput
func (BucketOutput) ElementType ¶
func (BucketOutput) ElementType() reflect.Type
func (BucketOutput) Endpoint ¶
func (o BucketOutput) Endpoint() pulumi.StringOutput
func (BucketOutput) Location ¶
func (o BucketOutput) Location() pulumi.StringOutput
func (BucketOutput) Result ¶
func (o BucketOutput) Result() pulumi.StringOutput
func (BucketOutput) Sk ¶
func (o BucketOutput) Sk() pulumi.StringOutput
func (BucketOutput) ToBucketOutput ¶
func (o BucketOutput) ToBucketOutput() BucketOutput
func (BucketOutput) ToBucketOutputWithContext ¶
func (o BucketOutput) ToBucketOutputWithContext(ctx context.Context) BucketOutput
type BucketState ¶
type BucketState struct {
}
func (BucketState) ElementType ¶
func (BucketState) ElementType() reflect.Type
type Provider ¶
type Provider struct {
pulumi.ProviderResourceState
}
func NewProvider ¶
func NewProvider(ctx *pulumi.Context, name string, args *ProviderArgs, opts ...pulumi.ResourceOption) (*Provider, error)
NewProvider registers a new resource with the given unique name, arguments, and options.
func (*Provider) ElementType ¶
func (*Provider) ToProviderOutput ¶
func (i *Provider) ToProviderOutput() ProviderOutput
func (*Provider) ToProviderOutputWithContext ¶
func (i *Provider) ToProviderOutputWithContext(ctx context.Context) ProviderOutput
type ProviderArgs ¶
type ProviderArgs struct {
Itsasecret pulumi.BoolPtrInput
}
The set of arguments for constructing a Provider resource.
func (ProviderArgs) ElementType ¶
func (ProviderArgs) ElementType() reflect.Type
type ProviderInput ¶
type ProviderInput interface {
pulumi.Input
ToProviderOutput() ProviderOutput
ToProviderOutputWithContext(ctx context.Context) ProviderOutput
}
type ProviderOutput ¶
type ProviderOutput struct{ *pulumi.OutputState }
func (ProviderOutput) ElementType ¶
func (ProviderOutput) ElementType() reflect.Type
func (ProviderOutput) ToProviderOutput ¶
func (o ProviderOutput) ToProviderOutput() ProviderOutput
func (ProviderOutput) ToProviderOutputWithContext ¶
func (o ProviderOutput) ToProviderOutputWithContext(ctx context.Context) ProviderOutput
type Random ¶
type Random struct {
pulumi.CustomResourceState
Length pulumi.IntOutput `pulumi:"length"`
Result pulumi.StringOutput `pulumi:"result"`
}
func GetRandom ¶
func GetRandom(ctx *pulumi.Context, name string, id pulumi.IDInput, state *RandomState, opts ...pulumi.ResourceOption) (*Random, error)
GetRandom gets an existing Random resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).
func NewRandom ¶
func NewRandom(ctx *pulumi.Context, name string, args *RandomArgs, opts ...pulumi.ResourceOption) (*Random, error)
NewRandom registers a new resource with the given unique name, arguments, and options.
func (*Random) ElementType ¶
func (*Random) ToRandomOutput ¶
func (i *Random) ToRandomOutput() RandomOutput
func (*Random) ToRandomOutputWithContext ¶
func (i *Random) ToRandomOutputWithContext(ctx context.Context) RandomOutput
type RandomArgs ¶
The set of arguments for constructing a Random resource.
func (RandomArgs) ElementType ¶
func (RandomArgs) ElementType() reflect.Type
type RandomComponent ¶
type RandomComponent struct {
pulumi.ResourceState
Length pulumi.IntOutput `pulumi:"length"`
Password pulumi.StringOutput `pulumi:"password"`
}
func NewRandomComponent ¶
func NewRandomComponent(ctx *pulumi.Context, name string, args *RandomComponentArgs, opts ...pulumi.ResourceOption) (*RandomComponent, error)
NewRandomComponent registers a new resource with the given unique name, arguments, and options.
func (*RandomComponent) ElementType ¶
func (*RandomComponent) ElementType() reflect.Type
func (*RandomComponent) ToRandomComponentOutput ¶
func (i *RandomComponent) ToRandomComponentOutput() RandomComponentOutput
func (*RandomComponent) ToRandomComponentOutputWithContext ¶
func (i *RandomComponent) ToRandomComponentOutputWithContext(ctx context.Context) RandomComponentOutput
type RandomComponentArgs ¶
The set of arguments for constructing a RandomComponent resource.
func (RandomComponentArgs) ElementType ¶
func (RandomComponentArgs) ElementType() reflect.Type
type RandomComponentInput ¶
type RandomComponentInput interface {
pulumi.Input
ToRandomComponentOutput() RandomComponentOutput
ToRandomComponentOutputWithContext(ctx context.Context) RandomComponentOutput
}
type RandomComponentOutput ¶
type RandomComponentOutput struct{ *pulumi.OutputState }
func (RandomComponentOutput) ElementType ¶
func (RandomComponentOutput) ElementType() reflect.Type
func (RandomComponentOutput) Length ¶
func (o RandomComponentOutput) Length() pulumi.IntOutput
func (RandomComponentOutput) Password ¶
func (o RandomComponentOutput) Password() pulumi.StringOutput
func (RandomComponentOutput) ToRandomComponentOutput ¶
func (o RandomComponentOutput) ToRandomComponentOutput() RandomComponentOutput
func (RandomComponentOutput) ToRandomComponentOutputWithContext ¶
func (o RandomComponentOutput) ToRandomComponentOutputWithContext(ctx context.Context) RandomComponentOutput
type RandomInput ¶
type RandomInput interface {
pulumi.Input
ToRandomOutput() RandomOutput
ToRandomOutputWithContext(ctx context.Context) RandomOutput
}
type RandomOutput ¶
type RandomOutput struct{ *pulumi.OutputState }
func (RandomOutput) ElementType ¶
func (RandomOutput) ElementType() reflect.Type
func (RandomOutput) Length ¶
func (o RandomOutput) Length() pulumi.IntOutput
func (RandomOutput) Result ¶
func (o RandomOutput) Result() pulumi.StringOutput
func (RandomOutput) ToRandomOutput ¶
func (o RandomOutput) ToRandomOutput() RandomOutput
func (RandomOutput) ToRandomOutputWithContext ¶
func (o RandomOutput) ToRandomOutputWithContext(ctx context.Context) RandomOutput
type RandomState ¶
type RandomState struct {
}
func (RandomState) ElementType ¶
func (RandomState) ElementType() reflect.Type